Crate prek_identify
prek_
identify
0.3.9
All Items
Crate Items
Modules
Structs
Enums
Functions
Crate
prek_
identify
Modules

tags
Structs

TagSet
A compact set of file tags represented as a fixed-size bitset.
TagSet
Iter
Enums

Error
Shebang
Error
Functions

parse_
shebang
tags_
from_
path
Identify tags for a file at the given path.